function [pP,roi] = wcPtable(wc,roi,~)

% print_Ptable takes struct from wcRjl as input and outputs table of
% mean (1-P)-values, i.e., no-change probabilities for region of interest, roi
%
% wcPtable(wc,roi);
%
% input wc is struct from wcRjl, roi is region of interest
%   if roi is colour image, draw ROI with colour image as backdrop
% if number of input parameters is 3, set rho = 1 and omega2 = 0

% (c) Copyright 2016
% Allan Aasbjerg Nielsen, PhD
% alan@dtu.dk, http://people.compute.dtu.dk/alan
% 14-17 Jan 2016

if ~isstruct(wc)
    error('wc must be struct as output from wcRjl')
end
if isfield(wc,'sumMat')
    nsets = size(wc,2);
else
    nsets = size(wc,2) + 1;
end

if ~ismatrix(roi)
    figure, roi = roipoly(roi);%roipolysarrgb(roi);
end

if size(wc(nsets-1).P) ~= size(roi)
    error('wcPtable: image and roi must be same size')
end

k = nsets;
pP = nan(k,k-1);

if nargin<3
    
    if ismatrix(wc(nsets-1).P) % two time points only: copy lnQ to lnR
        wc(nsets-1).P(:,:,2) = wc(nsets-1).P;
        wc(nsets-1).P(:,:,1) = wc(nsets-1).P(:,:,2);
    end
    
    figure
    % no-change probability
    for ell=1:(k-1) % Q
        Paux = 1 - wc(ell).P(:,:,1);
        Paux = Paux(roi);
        % figure,imshow(Paux.*(1-double(roi)),[0 1])
        subplot(k,k-1,ell), histogram(Paux,0:0.05:1);
        pP(1,ell) = mean(Paux);
    end
    for ell=1:(k-1)
        m = 2;
        for r=(1+ell):k
            n = (k-1)*(r-1)+1+ell-1;
            %         fprintf('r=%i, ell=%i, n=%i\n',r,ell,n)
            Paux = 1 - wc(ell).P(:,:,m);
            Paux = Paux(roi);
            % figure,imshow(Paux.*(1-double(roi)),[0 1])
            subplot(k,k-1,n), histogram(Paux,0:0.05:1);
            pP(r,ell) = mean(Paux);
            m = m + 1;
        end
    end
  
else % rho = 1, omega2 = 0

    if isscalar(wc(nsets-1).f) % two time points only: copy lnQ to lnR
        wc(nsets-1).lnR(:,:,2) = wc(nsets-1).lnR;
        wc(nsets-1).lnR(:,:,1) = wc(nsets-1).lnR(:,:,2);
        wc(nsets-1).f(2) = wc(nsets-1).f;
        wc(nsets-1).f(1) = wc(nsets-1).f(2);
    end
    
    figure
    % no-change probability
    for ell=1:(k-1) % Q
        Paux = wc(ell).lnR(:,:,1);
        Paux = Paux(roi);
        Paux = 1 - gammainc(-Paux,0.5*wc(ell).f(1));
        % figure,imshow(Paux.*(1-double(roi)),[0 1])
        subplot(k,k-1,ell), histogram(Paux,0:0.05:1);
        pP(1,ell) = mean(Paux);
    end
    for ell=1:(k-1)
        m = 2;
        for r=(1+ell):k
            n = (k-1)*(r-1)+1+ell-1;
            %         fprintf('r=%i, ell=%i, n=%i\n',r,ell,n)
            Paux = wc(ell).lnR(:,:,m);
            Paux = Paux(roi);
            Paux = 1 - gammainc(-Paux,0.5*wc(ell).f(m));
            % figure,imshow(Paux.*(1-double(roi)),[0 1])
            subplot(k,k-1,n), histogram(Paux,0:0.05:1);
            pP(r,ell) = mean(Paux);
            m = m + 1;
        end
    end

end

return

figure%('Name','Grass')
plot((3.5:1:7.5).',pP(1,:),'o-k','LineWidth',2);
grid on
hold on
plot((3.5:1:7.5).',pP(2:end,:),'o-','LineWidth',2);
axis0 = axis;
% axis([2 9 axis0(3:4)])
axis([2 9 0 axis0(4)])
plot([2 9],[0.01 0.01],'--')
plot([2 9],[0.05 0.05],'--')
xlabel('Month')
ylabel('No-change prob.')
legend('Q^{(l)}','R_j^{(1)}','R_j^{(2)}','R_j^{(3)}','R_j^{(4)}','R_j^{(5)}',...
    'Location','NorthEast')
%     'Location','SouthEast')
%     'Location','NorthWest')
%     'Location','SouthWest')
